@@ -1,5 +1,5 @@
 /* cclive
- * Copyright (C) 2010-2011  Toni Gundogdu <legatvs@gmail.com>
+ * Copyright (C) 2010-2013  Toni Gundogdu <legatvs@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <ccinternal>
+
+#include <stdexcept>
 #include <iostream>
+#include <clocale>
 
 #include <ccapplication>
 #include <ccquvi>
@@ -24,27 +28,26 @@ using namespace cc;
 
 int main(int argc, char *argv[])
 {
+  setlocale(LC_ALL, "");
+  application::exit_status es = application::ok;
   application app;
-  int rc = 0; // OK.
-
   try
     {
-      rc = app.exec(argc,argv);
+      es = app.exec(argc, argv);
     }
-
   // Thrown by quvi::query constructor (e.g. quvi_init failure).
   catch (const quvi::error& e)
     {
       std::clog << "libquvi: error: " << e.what() << std::endl;
+      es = application::error;
     }
-
   // Thrown by boost (e.g. cc::go_background failure).
   catch (const std::runtime_error& e)
     {
       std::clog << "error: " << e.what() << std::endl;
+      es = application::error;
     }
-
-  return rc;
+  return es;
 }
 
 // vim: set ts=2 sw=2 tw=72 expandtab:
